@@ -14,7 +14,7 @@ import copy
 import logging
 from collections import defaultdict, deque, namedtuple
 
-from botocore.compat import accepts_kwargs, six
+from botocore.compat import accepts_kwargs
 
 logger = logging.getLogger(__name__)
 
@@ -143,7 +143,7 @@ class BaseEventHooks(object):
         pass
 
     def _verify_is_callable(self, func):
-        if not six.callable(func):
+        if not callable(func):
             raise ValueError("Event handler %s must be callable." % func)
 
     def _verify_accept_kwargs(self, func):
