@@ -21,6 +21,8 @@ import logging
 import re
 from enum import Enum
 
+import jmespath
+
 from botocore import UNSIGNED, xform_name
 from botocore.auth import AUTH_TYPE_MAPS
 from botocore.endpoint_provider import EndpointProvider
@@ -402,7 +404,9 @@ class EndpointResolverBuiltins(str, Enum):
     AWS_S3_DISABLE_MRAP = "AWS::S3::DisableMultiRegionAccessPoints"
     # Whether a custom endpoint has been configured (str)
     SDK_ENDPOINT = "SDK::Endpoint"
-
+    # Currently not implemented:
+    ACCOUNT_ID = "AWS::Auth::AccountId"
+    ACCOUNT_ID_ENDPOINT_MODE = "AWS::Auth::AccountIdEndpointMode"
 
 class EndpointRulesetResolver:
     """Resolves endpoints using a service's endpoint ruleset"""
@@ -528,6 +532,13 @@ class EndpointRulesetResolver:
         )
         if dynamic is not None:
             return dynamic
+        operation_context_params = (
+            self._resolve_param_as_operation_context_param(
+                param_name, operation_model, call_args
+            )
+        )
+        if operation_context_params is not None:
+            return operation_context_params
         return self._resolve_param_as_client_context_param(param_name)
 
     def _resolve_param_as_static_context_param(
@@ -550,6 +561,14 @@ class EndpointRulesetResolver:
             client_ctx_varname = client_ctx_params[param_name]
             return self._client_context.get(client_ctx_varname)
 
+    def _resolve_param_as_operation_context_param(
+        self, param_name, operation_model, call_args
+    ):
+        operation_ctx_params = operation_model.operation_context_parameters
+        if param_name in operation_ctx_params:
+            path = operation_ctx_params[param_name]['path']
+            return jmespath.search(path, call_args)
+
     def _resolve_param_as_builtin(self, builtin_name, builtins):
         if builtin_name not in EndpointResolverBuiltins.__members__.values():
             raise UnknownEndpointResolutionBuiltInName(name=builtin_name)
@@ -662,7 +681,9 @@ class EndpointRulesetResolver:
             signing_context['region'] = scheme['signingRegion']
         elif 'signingRegionSet' in scheme:
             if len(scheme['signingRegionSet']) > 0:
-                signing_context['region'] = scheme['signingRegionSet'][0]
+                signing_context['region'] = ','.join(
+                    scheme['signingRegionSet']
+                )
         if 'signingName' in scheme:
             signing_context.update(signing_name=scheme['signingName'])
         if 'disableDoubleEncoding' in scheme:
