@@ -22,14 +22,10 @@ from zlib import error as ZLibError
 from datetime import datetime, timedelta
 from dateutil import tz, parser
 
-import cryptography
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives.asymmetric.padding import PKCS1v15
-from cryptography.hazmat.primitives.serialization import load_der_public_key
+from awscrt.crypto import RSA, RSASignatureAlgorithm
 
 from awscli.customizations.cloudtrail.utils import get_trail_by_arn, \
-    get_account_id_from_arn
+    get_account_id_from_arn, PublicKeyProvider
 from awscli.customizations.commands import BasicCommand
 from awscli.customizations.exceptions import ParamValidationError
 from botocore.exceptions import ClientError
@@ -219,29 +215,6 @@ class InvalidDigestFormat(DigestError):
         super(InvalidDigestFormat, self).__init__(message)
 
 
-class PublicKeyProvider(object):
-    """Retrieves public keys from CloudTrail within a date range."""
-    def __init__(self, cloudtrail_client):
-        self._cloudtrail_client = cloudtrail_client
-
-    def get_public_keys(self, start_date, end_date):
-        """Loads public keys in a date range into a returned dict.
-
-        :type start_date: datetime
-        :param start_date: Start date of a date range.
-        :type end_date: datetime
-        :param end_date: End date of a date range.
-        :rtype: dict
-        :return: Returns a dict where each key is the fingerprint of the
-            public key, and each value is a dict of public key data.
-        """
-        public_keys = self._cloudtrail_client.list_public_keys(
-            StartTime=start_date, EndTime=end_date)
-        public_keys_in_range = public_keys['PublicKeyList']
-        LOG.debug('Loaded public keys in range: %s', public_keys_in_range)
-        return dict((key['Fingerprint'], key) for key in public_keys_in_range)
-
-
 class DigestProvider(object):
     """
     Retrieves digest keys and digests from Amazon S3.
@@ -578,18 +551,24 @@ class Sha256RSADigestValidator(object):
         """
         try:
             decoded_key = base64.b64decode(public_key)
-            public_key = load_der_public_key(decoded_key, default_backend())
-            to_sign = self._create_string_to_sign(digest_data, inflated_digest)
-            signature_bytes = binascii.unhexlify(digest_data['_signature'])
-            hashing = hashes.SHA256()
-            public_key.verify(signature_bytes, to_sign, PKCS1v15(), hashing)
-        except ValueError:
+            public_key = RSA.new_public_key_from_der_data(decoded_key)
+        except RuntimeError:
             raise DigestError(
                 ('Digest file\ts3://%s/%s\tINVALID: Unable to load PKCS #1 key'
                  ' with fingerprint %s')
                 % (bucket, key, digest_data['digestPublicKeyFingerprint']))
-        except cryptography.exceptions.InvalidSignature:
-            # Don't display the stack trace of a signature exception to avoid
+
+        to_sign = self._create_string_to_sign(digest_data, inflated_digest)
+        signature_bytes = binascii.unhexlify(digest_data['_signature'])
+
+        result = public_key.verify(
+            signature_algorithm=RSASignatureAlgorithm.PKCS1_5_SHA256, 
+            digest=hashlib.sha256(to_sign).digest(), 
+            signature=signature_bytes
+        )
+        if not result:
+            # The previous implementation caught a cryptography.exceptions.InvalidSignature
+            # exception here and re-raised the DigestSignatureError to avoid the stack trace
             # leaking any information about the key.
             raise DigestSignatureError(bucket, key)
 
