@@ -46,12 +46,14 @@ class LoginCommand(BaseSSOCommand):
             on_pending_authorization = PrintOnlyHandler()
         do_sso_login(
             session=self._session,
+            parsed_globals=parsed_globals,
             sso_region=sso_config['sso_region'],
             start_url=sso_config['sso_start_url'],
             on_pending_authorization=on_pending_authorization,
             force_refresh=True,
             session_name=sso_config.get('session_name'),
             registration_scopes=sso_config.get('registration_scopes'),
+            use_device_code=parsed_args.use_device_code,
         )
         success_msg = 'Successfully logged into Start URL: %s\n'
         uni_print(success_msg % sso_config['sso_start_url'])
