@@ -35,6 +35,7 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     'cloudfront.ListCloudFrontOriginAccessIdentities.CloudFrontOriginAccessIdentityList',
     'cloudfront.ListDistributions.DistributionList',
     'cloudfront.ListInvalidations.InvalidationList',
+    'cloudfront.ListPublicKeys.PublicKeyList',
     'cloudfront.ListStreamingDistributions.StreamingDistributionList',
     'cloudfront.ListKeyValueStores.KeyValueStoreList',
     'codedeploy.ListDeploymentGroups.applicationName',
@@ -76,7 +77,6 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     'route53.ListResourceRecordSets.MaxItems',
     's3.ListMultipartUploads.Delimiter',
     's3.ListMultipartUploads.KeyMarker',
-    's3.ListMultipartUploads.Prefix',
     's3.ListMultipartUploads.Bucket',
     's3.ListMultipartUploads.MaxUploads',
     's3.ListMultipartUploads.UploadIdMarker',
@@ -85,13 +85,11 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     's3.ListObjectVersions.Delimiter',
     's3.ListObjectVersions.VersionIdMarker',
     's3.ListObjectVersions.KeyMarker',
-    's3.ListObjectVersions.Prefix',
     's3.ListObjectVersions.Name',
     's3.ListObjectVersions.EncodingType',
     's3.ListObjects.MaxKeys',
     's3.ListObjects.Delimiter',
     's3.ListObjects.NextMarker',
-    's3.ListObjects.Prefix',
     's3.ListObjects.Marker',
     's3.ListObjects.Name',
     's3.ListObjects.EncodingType',
@@ -100,7 +98,6 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     's3.ListObjectsV2.Delimiter',
     's3.ListObjectsV2.ContinuationToken',
     's3.ListObjectsV2.KeyCount',
-    's3.ListObjectsV2.Prefix',
     's3.ListObjectsV2.Name',
     's3.ListObjectsV2.EncodingType',
     's3.ListParts.PartNumberMarker',
