@@ -10,7 +10,6 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import mock
 import os
 
 from awscrt.s3 import S3Request
@@ -18,10 +17,9 @@ from botocore.awsrequest import AWSResponse
 
 from tests import CLIRunner, SessionStubber, HTTPResponse
 from awscli.clidriver import AWSCLIEntryPoint
-from awscli.testutils import unittest, create_clidriver, temporary_file
+from awscli.testutils import unittest, create_clidriver, temporary_file, mock
 from awscli.testutils import BaseAWSCommandParamsTest, FileCreator
-from awscli.compat import six, urlparse
-
+from awscli.compat import urlparse, BytesIO
 
 class BaseS3TransferCommandTest(BaseAWSCommandParamsTest):
     def setUp(self):
@@ -95,7 +93,7 @@ class BaseS3TransferCommandTest(BaseAWSCommandParamsTest):
     def get_object_response(self):
         return {
             'ETag': '"foo-1"',
-            'Body': six.BytesIO(b'foo')
+            'Body': BytesIO(b'foo')
         }
 
     def copy_object_response(self):
@@ -151,6 +149,7 @@ class BaseS3TransferCommandTest(BaseAWSCommandParamsTest):
         params = {
             'Bucket': bucket,
             'Key': key,
+            'ChecksumAlgorithm': 'CRC64NVME',
             'Body': mock.ANY,
         }
         params.update(override_kwargs)
@@ -344,7 +343,7 @@ class BaseS3CLIRunnerTest(unittest.TestCase):
 
     def add_botocore_get_object_response(self):
         self.cli_runner.add_response(
-            HTTPResponse(headers={'ETag': '"foo-1"'}, body=six.BytesIO(b'foo'))
+            HTTPResponse(headers={'ETag': '"foo-1"'}, body=BytesIO(b'foo'))
         )
 
     def add_botocore_copy_object_response(self):
