@@ -27,10 +27,10 @@ import socket
 import tempfile
 import copy
 
-from awscli.compat import six, urlopen
 from dateutil.tz import tzutc
 import pytest
 
+from awscli.compat import BytesIO, urlopen
 from awscli.testutils import unittest, get_stdout_encoding
 from awscli.testutils import skip_if_windows
 from awscli.testutils import aws as _aws
@@ -39,6 +39,9 @@ from awscli.customizations.s3.transferconfig import DEFAULTS
 from tests.integration.customizations.s3 import BaseS3IntegrationTest
 
 
+_NON_EXISTENT_BUCKET = random_bucket_name()
+
+
 @pytest.fixture
 def symlink_files(files):
     nested_dir = os.path.join(files.rootdir, 'realfiles')
@@ -165,7 +168,10 @@ class BaseParameterizedS3ClientTest(BaseS3IntegrationTest):
 
 
 class TestMoveCommand(BaseParameterizedS3ClientTest):
-    def test_mv_local_to_s3(self, files, s3_utils, shared_bucket):
+    @pytest.mark.parametrize('s3_bucket', [
+        'shared_bucket', 'shared_dir_bucket'])
+    def test_mv_local_to_s3(self, s3_bucket, files, s3_utils, request):
+        shared_bucket = request.getfixturevalue(s3_bucket)
         full_path = files.create_file('foo.txt', 'this is foo.txt')
         p = aws('s3 mv %s s3://%s/foo.txt' % (full_path,
                                               shared_bucket))
@@ -176,9 +182,12 @@ class TestMoveCommand(BaseParameterizedS3ClientTest):
         s3_utils.assert_key_contents_equal(
             shared_bucket, 'foo.txt', 'this is foo.txt')
 
-    def test_mv_s3_to_local(self, files, s3_utils, shared_bucket):
+    @pytest.mark.parametrize('s3_bucket', [
+        'shared_bucket', 'shared_dir_bucket'])
+    def test_mv_s3_to_local(self, s3_bucket, files, s3_utils, request):
+        shared_bucket = request.getfixturevalue(s3_bucket)
         s3_utils.put_object(shared_bucket, 'foo.txt', 'this is foo.txt')
-        full_path = files.full_path('foo.txt')
+        full_path = files.full_path(f'{s3_bucket}_foo.txt')
         assert s3_utils.key_exists(shared_bucket, key_name='foo.txt')
         p = aws('s3 mv s3://%s/foo.txt %s' % (shared_bucket, full_path))
         self.assert_no_errors(p)
@@ -188,24 +197,34 @@ class TestMoveCommand(BaseParameterizedS3ClientTest):
         # The s3 file should not be there anymore.
         assert s3_utils.key_not_exists(shared_bucket, key_name='foo.txt')
 
-    def test_mv_s3_to_s3(self, s3_utils, shared_bucket, shared_copy_bucket):
-        from_bucket = shared_bucket
-        to_bucket = shared_copy_bucket
-        s3_utils.put_object(from_bucket, 'foo.txt', 'this is foo.txt')
+    @pytest.mark.parametrize('s3_bucket, copy_s3_bucket', [
+        ('shared_bucket', 'shared_copy_bucket'),
+        ('shared_bucket', 'shared_copy_dir_bucket'),
+        ('shared_dir_bucket', 'shared_copy_dir_bucket'),
+        ('shared_dir_bucket', 'shared_copy_bucket')])
+    def test_mv_s3_to_s3(self, s3_bucket, copy_s3_bucket, s3_utils, request):
+        from_bucket = request.getfixturevalue(s3_bucket)
+        to_bucket = request.getfixturevalue(copy_s3_bucket)
+        from_key = f'{s3_bucket}_foo.txt'
+        to_key = f'{copy_s3_bucket}_foo.txt'
+        s3_utils.put_object(from_bucket, from_key, 'this is foo.txt')
+
+        p = aws(
+            f"s3 mv s3://{from_bucket}/{from_key} s3://{to_bucket}/{to_key}"
+        )
 
-        p = aws('s3 mv s3://%s/foo.txt s3://%s/foo.txt' % (from_bucket,
-                                                           to_bucket))
         self.assert_no_errors(p)
-        contents = s3_utils.get_key_contents(to_bucket, 'foo.txt')
+        contents = s3_utils.get_key_contents(to_bucket, to_key)
         assert contents == 'this is foo.txt'
         # And verify that the object no longer exists in the from_bucket.
-        assert s3_utils.key_not_exists(from_bucket, key_name='foo.txt')
+        assert s3_utils.key_not_exists(from_bucket, key_name=from_key)
 
+    @pytest.mark.slow
     def test_mv_s3_to_s3_multipart(self, s3_utils, shared_bucket,
                                    shared_copy_bucket):
         from_bucket = shared_bucket
         to_bucket = shared_copy_bucket
-        file_contents = six.BytesIO(b'abcd' * (1024 * 1024 * 10))
+        file_contents = BytesIO(b'abcd' * (1024 * 1024 * 10))
         s3_utils.put_object(from_bucket, 'foo.txt', file_contents)
 
         p = aws('s3 mv s3://%s/foo.txt s3://%s/foo.txt' % (from_bucket,
@@ -220,7 +239,7 @@ class TestMoveCommand(BaseParameterizedS3ClientTest):
         from_bucket = shared_bucket
         to_bucket = shared_copy_bucket
 
-        large_file_contents = six.BytesIO(b'abcd' * (1024 * 1024 * 10))
+        large_file_contents = BytesIO(b'abcd' * (1024 * 1024 * 10))
         small_file_contents = 'small file contents'
         s3_utils.put_object(from_bucket, 'largefile', large_file_contents)
         s3_utils.put_object(from_bucket, 'smallfile', small_file_contents)
@@ -265,7 +284,7 @@ class TestMoveCommand(BaseParameterizedS3ClientTest):
 
     def test_mv_with_large_file(self, files, s3_utils, shared_bucket):
         # 40MB will force a multipart upload.
-        file_contents = six.BytesIO(b'abcd' * (1024 * 1024 * 10))
+        file_contents = BytesIO(b'abcd' * (1024 * 1024 * 10))
         foo_txt = files.create_file(
             'foo.txt', file_contents.getvalue().decode('utf-8'))
         p = aws('s3 mv %s s3://%s/foo.txt' % (foo_txt, shared_bucket))
@@ -284,7 +303,7 @@ class TestMoveCommand(BaseParameterizedS3ClientTest):
 
     def test_mv_to_nonexistent_bucket(self, files):
         full_path = files.create_file('foo.txt', 'this is foo.txt')
-        p = aws('s3 mv %s s3://bad-noexist-13143242/foo.txt' % (full_path,))
+        p = aws(f's3 mv {full_path} s3://{_NON_EXISTENT_BUCKET}/foo.txt')
         assert p.rc == 1
 
     def test_cant_move_file_onto_itself_small_file(self, s3_utils,
@@ -303,7 +322,7 @@ class TestMoveCommand(BaseParameterizedS3ClientTest):
         # but a mv command doesn't make sense because a mv is just a
         # cp + an rm of the src file.  We should be consistent and
         # not allow large files to be mv'd onto themselves.
-        file_contents = six.BytesIO(b'a' * (1024 * 1024 * 10))
+        file_contents = BytesIO(b'a' * (1024 * 1024 * 10))
         s3_utils.put_object(shared_bucket, key_name='key.txt',
                             contents=file_contents)
         p = aws('s3 mv s3://%s/key.txt s3://%s/key.txt' %
@@ -332,7 +351,10 @@ class TestRm(BaseParameterizedS3ClientTest):
         # And verify it's gone.
         assert s3_utils.key_not_exists(shared_bucket, key_name='foo\r.txt')
 
-    def test_rm_with_page_size(self, s3_utils, shared_bucket):
+    @pytest.mark.parametrize('s3_bucket', [
+        'shared_bucket', 'shared_dir_bucket'])
+    def test_rm_with_page_size(self, s3_bucket, s3_utils, request):
+        shared_bucket = request.getfixturevalue(s3_bucket)
         s3_utils.put_object(shared_bucket, 'foo.txt', contents='hello world')
         s3_utils.put_object(shared_bucket, 'bar.txt', contents='hello world2')
         p = aws('s3 rm s3://%s/ --recursive --page-size 1' % shared_bucket)
@@ -343,13 +365,16 @@ class TestRm(BaseParameterizedS3ClientTest):
 
 
 class TestCp(BaseParameterizedS3ClientTest):
-    def test_cp_to_and_from_s3(self, files, s3_utils, shared_bucket):
+    @pytest.mark.parametrize('s3_bucket', [
+        'shared_bucket', 'shared_dir_bucket'])
+    def test_cp_to_and_from_s3(self, s3_bucket, files, s3_utils, request):
         # This tests the ability to put a single file in s3
         # move it to a different bucket.
         # and download the file locally
+        shared_bucket = request.getfixturevalue(s3_bucket)
 
         # copy file into bucket.
-        foo_txt = files.create_file('foo.txt', 'this is foo.txt')
+        foo_txt = files.create_file(f'{s3_bucket}_foo.txt', 'this is foo.txt')
         p = aws('s3 cp %s s3://%s/foo.txt' % (foo_txt, shared_bucket))
         self.assert_no_errors(p)
 
@@ -362,7 +387,7 @@ class TestCp(BaseParameterizedS3ClientTest):
         assert content_type == 'text/plain'
 
         # Make a new name for the file and copy it locally.
-        full_path = files.full_path('bar.txt')
+        full_path = files.full_path(f'{s3_bucket}_bar.txt')
         p = aws('s3 cp s3://%s/foo.txt %s' % (shared_bucket, full_path))
         self.assert_no_errors(p)
 
@@ -384,11 +409,12 @@ class TestCp(BaseParameterizedS3ClientTest):
         contents = s3_utils.get_key_contents(shared_bucket, key_name='foo.txt')
         assert contents == 'this is foo.txt'
 
+    @pytest.mark.slow
     def test_cp_s3_s3_multipart(self, s3_utils, shared_bucket,
                                 shared_copy_bucket):
         from_bucket = shared_bucket
         to_bucket = shared_copy_bucket
-        file_contents = six.BytesIO(b'abcd' * (1024 * 1024 * 10))
+        file_contents = BytesIO(b'abcd' * (1024 * 1024 * 10))
         s3_utils.put_object(from_bucket, 'foo.txt', file_contents)
 
         p = aws('s3 cp s3://%s/foo.txt s3://%s/foo.txt' %
@@ -410,7 +436,7 @@ class TestCp(BaseParameterizedS3ClientTest):
 
     def test_download_large_file(self, files, s3_utils, shared_bucket):
         # This will force a multipart download.
-        foo_contents = six.BytesIO(b'abcd' * (1024 * 1024 * 10))
+        foo_contents = BytesIO(b'abcd' * (1024 * 1024 * 10))
         s3_utils.put_object(shared_bucket, key_name='foo.txt',
                             contents=foo_contents)
         local_foo_txt = files.full_path('foo.txt')
@@ -421,7 +447,7 @@ class TestCp(BaseParameterizedS3ClientTest):
     @skip_if_windows('SIGINT not supported on Windows.')
     def test_download_ctrl_c_does_not_hang(self, files, s3_utils,
                                            shared_bucket):
-        foo_contents = six.BytesIO(b'abcd' * (1024 * 1024 * 40))
+        foo_contents = BytesIO(b'abcd' * (1024 * 1024 * 40))
         s3_utils.put_object(shared_bucket, key_name='foo.txt',
                             contents=foo_contents)
         local_foo_txt = files.full_path('foo.txt')
@@ -470,7 +496,7 @@ class TestCp(BaseParameterizedS3ClientTest):
 
     def test_cp_to_nonexistent_bucket(self, files):
         foo_txt = files.create_file('foo.txt', 'this is foo.txt')
-        p = aws('s3 cp %s s3://noexist-bucket-foo-bar123/foo.txt' % (foo_txt,))
+        p = aws(f's3 cp {foo_txt} s3://{_NON_EXISTENT_BUCKET}/foo.txt')
         assert p.rc == 1
 
     def test_cp_empty_file(self, files, s3_utils, shared_bucket):
@@ -481,7 +507,7 @@ class TestCp(BaseParameterizedS3ClientTest):
         assert s3_utils.key_exists(shared_bucket, 'foo.txt')
 
     def test_download_non_existent_key(self):
-        p = aws('s3 cp s3://jasoidfjasdjfasdofijasdf/foo.txt foo.txt')
+        p = aws(f's3 cp s3://{_NON_EXISTENT_BUCKET}/foo.txt foo.txt')
         assert p.rc == 1
         expected_err_msg = (
             'An error occurred (404) when calling the '
@@ -731,7 +757,7 @@ class TestSync(BaseParameterizedS3ClientTest):
         files.create_file('bar.txt', 'bar contents')
 
         # Sync the directory and the bucket.
-        p = aws('s3 sync %s s3://noexist-bkt-nme-1412' % (files.rootdir,))
+        p = aws(f's3 sync {files.rootdir} s3://{_NON_EXISTENT_BUCKET}')
         assert p.rc == 1
 
     def test_sync_with_empty_files(self, files, s3_utils, shared_bucket):
@@ -976,7 +1002,7 @@ class TestUnableToWriteToFile(BaseParameterizedS3ClientTest):
         # which effectively disables the expect 100 continue logic.
         # This will result in a test error because we won't follow
         # the temporary redirect for the newly created bucket.
-        contents = six.BytesIO(b'a' * 10 * 1024 * 1024)
+        contents = BytesIO(b'a' * 10 * 1024 * 1024)
         s3_utils.put_object(shared_bucket, 'foo.txt',
                             contents=contents)
         os.chmod(files.rootdir, 0o444)
@@ -1113,7 +1139,7 @@ class TestLs(BaseS3IntegrationTest):
         self.assert_no_errors(p)
 
     def test_ls_non_existent_bucket(self):
-        p = aws('s3 ls s3://foobara99842u4wbts829381')
+        p = aws(f's3 ls s3://{_NON_EXISTENT_BUCKET}')
         assert p.rc == 254
         error_msg = (
             'An error occurred (NoSuchBucket) when calling the '
@@ -1123,7 +1149,10 @@ class TestLs(BaseS3IntegrationTest):
         # There should be no stdout if we can't find the bucket.
         assert p.stdout == ''
 
-    def test_ls_with_prefix(self, s3_utils, shared_bucket):
+    @pytest.mark.parametrize('s3_bucket', [
+        'shared_bucket', 'shared_dir_bucket'])
+    def test_ls_with_prefix(self, s3_bucket, s3_utils, request):
+        shared_bucket = request.getfixturevalue(s3_bucket)
         s3_utils.put_object(shared_bucket, 'foo.txt', 'contents')
         s3_utils.put_object(shared_bucket, 'foo', 'contents')
         s3_utils.put_object(shared_bucket, 'bar.txt', 'contents')
@@ -1134,7 +1163,10 @@ class TestLs(BaseS3IntegrationTest):
         assert '8 foo' in p.stdout
         assert '8 bar.txt' in p.stdout
 
-    def test_ls_recursive(self, s3_utils, shared_bucket):
+    @pytest.mark.parametrize('s3_bucket', [
+        'shared_bucket', 'shared_dir_bucket'])
+    def test_ls_recursive(self, s3_bucket, s3_utils, request):
+        shared_bucket = request.getfixturevalue(s3_bucket)
         s3_utils.put_object(shared_bucket, 'foo.txt', 'contents')
         s3_utils.put_object(shared_bucket, 'foo', 'contents')
         s3_utils.put_object(shared_bucket, 'bar.txt', 'contents')
@@ -1250,7 +1282,7 @@ class TestOutput(BaseParameterizedS3ClientTest):
         foo_txt = files.create_file('foo.txt', 'foo contents')
 
         # Copy file into bucket.
-        p = aws('s3 cp %s s3://non-existant-bucket/' % foo_txt)
+        p = aws(f's3 cp {foo_txt} s3://{_NON_EXISTENT_BUCKET}/')
         # Check that there were errors and that the error was print to stderr.
         assert p.rc == 1
         assert 'upload failed' in p.stderr
@@ -1259,7 +1291,7 @@ class TestOutput(BaseParameterizedS3ClientTest):
         foo_txt = files.create_file('foo.txt', 'foo contents')
 
         # Copy file into bucket.
-        p = aws('s3 cp %s s3://non-existant-bucket/ --quiet' % foo_txt)
+        p = aws(f's3 cp {foo_txt} s3://{_NON_EXISTENT_BUCKET}/ --quiet')
         # Check that there were errors and that the error was not
         # print to stderr.
         assert p.rc == 1
@@ -1269,8 +1301,7 @@ class TestOutput(BaseParameterizedS3ClientTest):
         foo_txt = files.create_file('foo.txt', 'foo contents')
 
         # Copy file into bucket.
-        p = aws('s3 cp %s s3://non-existant-bucket/ --only-show-errors'
-                % foo_txt)
+        p = aws(f's3 cp {foo_txt} s3://{_NON_EXISTENT_BUCKET}/ --only-show-errors')
         # Check that there were errors and that the error was print to stderr.
         assert p.rc == 1
         assert 'upload failed' in p.stderr
