@@ -13,6 +13,9 @@
 import glob
 import io
 import os
+from uuid import uuid4
+
+from botocore.exceptions import ClientError
 
 from s3transfer.subscribers import BaseSubscriber
 from s3transfer.utils import OSUtils
