@@ -14,9 +14,11 @@ import unittest
 from io import BytesIO
 
 from tests import mock
+from tests.utils.botocore import get_checksum_cls
 
 from botocore.awsrequest import AWSResponse
-from botocore.model import OperationModel
+from botocore.model import OperationModel, StringShape, StructureShape
+from botocore.config import Config
 from botocore.exceptions import AwsChunkedWrapperError
 from botocore.exceptions import FlexibleChecksumError
 from botocore.httpchecksum import AwsChunkedWrapper
@@ -24,15 +26,15 @@ from botocore.httpchecksum import StreamingChecksumBody
 from botocore.httpchecksum import (
     Crc32Checksum,
     Sha256Checksum,
+    CrtCrc64NvmeChecksum,
     Sha1Checksum,
-    CrtCrc32Checksum,
     CrtCrc32cChecksum,
-)
-from botocore.httpchecksum import (
+    CrtCrc32Checksum,
+    CrtCrc64NvmeChecksum,
     apply_request_checksum,
+    handle_checksum_body,
     resolve_request_checksum_algorithm,
     resolve_response_checksum_algorithms,
-    handle_checksum_body,
 )
 
 
@@ -51,6 +53,13 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         operation.http_checksum_required = required
         operation.has_streaming_output = streaming_output
         operation.has_streaming_input = streaming_input
+        if http_checksum and "requestAlgorithmMember" in http_checksum:
+            shape = mock.Mock(spec=StringShape)
+            shape.serialization = {"name": "x-amz-request-algorithm"}
+            operation.input_shape = mock.Mock(spec=StructureShape)
+            operation.input_shape.members = {
+                http_checksum["requestAlgorithmMember"]: shape
+            }
         return operation
 
     def _make_http_response(
@@ -82,7 +91,11 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         request = {
             "headers": {},
             "body": body,
-            "context": {},
+            "context": {
+                "client_config": Config(
+                    request_checksum_calculation="when_supported",
+                )
+            },
             "url": "https://example.com",
         }
         return request
@@ -94,94 +107,165 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         resolve_request_checksum_algorithm(request, operation_model, params)
         self.assertNotIn("checksum", request["context"])
 
-    def test_request_checksum_algorithm_model_opt_in(self):
+    def test_request_checksum_algorithm_model_default(self):
         operation_model = self._make_operation_model(
             http_checksum={"requestAlgorithmMember": "Algorithm"}
         )
 
-        # Param is not present, no checksum will be set
+        # Param is not present, crc64 checksum will be set by default
         params = {}
         request = self._build_request(b"")
         resolve_request_checksum_algorithm(request, operation_model, params)
-        self.assertNotIn("checksum", request["context"])
+        expected_algorithm = {
+            "algorithm": "crc64nvme",
+            "in": "header",
+            "name": "x-amz-checksum-crc64nvme",
+        }
+        expected_request_algorithm_header = {
+            "name": "x-amz-request-algorithm",
+            "value": "CRC64NVME",
+        }
+        actual_algorithm = request["context"]["checksum"]["request_algorithm"]
+        actual_request_algorithm_header = request["context"]["checksum"][
+            "request_algorithm_header"
+        ]
+        self.assertEqual(actual_algorithm, expected_algorithm)
+        self.assertEqual(
+            actual_request_algorithm_header, expected_request_algorithm_header
+        )
 
-        # Param is present, crc32 checksum will be set
-        params = {"Algorithm": "crc32"}
+        # Param is present, sha256 checksum will be set
+        params = {"Algorithm": "sha256"}
         request = self._build_request(b"")
         resolve_request_checksum_algorithm(request, operation_model, params)
         expected_algorithm = {
-            "algorithm": "crc32",
+            "algorithm": "sha256",
             "in": "header",
-            "name": "x-amz-checksum-crc32",
+            "name": "x-amz-checksum-sha256",
         }
         actual_algorithm = request["context"]["checksum"]["request_algorithm"]
         self.assertEqual(actual_algorithm, expected_algorithm)
 
         # Param present but header already set, checksum should be skipped
-        params = {"Algorithm": "crc32"}
+        params = {"Algorithm": "crc64nvme"}
         request = self._build_request(b"")
-        request["headers"]["x-amz-checksum-crc32"] = "foo"
+        request["headers"]["x-amz-checksum-crc64nvme"] = "foo"
         resolve_request_checksum_algorithm(request, operation_model, params)
         self.assertNotIn("checksum", request["context"])
 
-    def test_request_checksum_algorithm_model_opt_in_streaming(self):
+    def test_request_checksum_algorithm_model_default_streaming(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model(
             http_checksum={"requestAlgorithmMember": "Algorithm"},
             streaming_input=True,
         )
 
-        # Param is not present, no checksum will be set
+        # Param is not present, crc64 checksum will be set
         params = {}
         resolve_request_checksum_algorithm(request, operation_model, params)
-        self.assertNotIn("checksum", request["context"])
-
-        # Param is present, crc32 checksum will be set in the trailer
-        params = {"Algorithm": "crc32"}
-        resolve_request_checksum_algorithm(request, operation_model, params)
         expected_algorithm = {
-            "algorithm": "crc32",
+            "algorithm": "crc64nvme",
             "in": "trailer",
-            "name": "x-amz-checksum-crc32",
+            "name": "x-amz-checksum-crc64nvme",
+        }
+        expected_request_algorithm_header = {
+            "name": "x-amz-request-algorithm",
+            "value": "CRC64NVME",
         }
         actual_algorithm = request["context"]["checksum"]["request_algorithm"]
         self.assertEqual(actual_algorithm, expected_algorithm)
 
+        # Param is present, sha256 checksum will be set in the trailer
+        params = {"Algorithm": "sha256"}
+        resolve_request_checksum_algorithm(request, operation_model, params)
+        expected_algorithm = {
+            "algorithm": "sha256",
+            "in": "trailer",
+            "name": "x-amz-checksum-sha256",
+        }
+        actual_algorithm = request["context"]["checksum"]["request_algorithm"]
+        actual_request_algorithm_header = request["context"]["checksum"][
+            "request_algorithm_header"
+        ]
+        self.assertEqual(actual_algorithm, expected_algorithm)
+        self.assertEqual(
+            actual_request_algorithm_header, expected_request_algorithm_header
+        )
+
         # Trailer should not be used for http endpoints
         request = self._build_request(b"")
         request["url"] = "http://example.com"
         resolve_request_checksum_algorithm(request, operation_model, params)
         expected_algorithm = {
-            "algorithm": "crc32",
+            "algorithm": "sha256",
             "in": "header",
-            "name": "x-amz-checksum-crc32",
+            "name": "x-amz-checksum-sha256",
         }
         actual_algorithm = request["context"]["checksum"]["request_algorithm"]
         self.assertEqual(actual_algorithm, expected_algorithm)
 
+    def test_request_checksum_algorithm_s3_signature_version_input_streaming(
+            self,
+    ):
+        config = Config(signature_version="s3")
+        request = self._build_request(b"")
+        request["context"]["client_config"] = config
+        operation_model = self._make_operation_model(
+            http_checksum={"requestChecksumRequired": True},
+            streaming_input=True,
+        )
+
+        params = {}
+        resolve_request_checksum_algorithm(request, operation_model, params)
+        actual_algorithm = request["context"]["checksum"]["request_algorithm"]
+        # Operations with streaming input using the "s3" signature_version should send
+        # checksums in the header, not trailer.
+        expected_algorithm = {
+            "algorithm": "crc64nvme",
+            "in": "header",
+            "name": "x-amz-checksum-crc64nvme",
+        }
+        self.assertEqual(actual_algorithm, expected_algorithm)
+
+    def test_request_checksum_algorithm_presigned_request(self):
+        request = self._build_request(b"")
+        request["context"]["is_presign_request"] = True
+        operation_model = self._make_operation_model(
+            http_checksum={"requestChecksumRequired": True},
+        )
+
+        params = {}
+        resolve_request_checksum_algorithm(request, operation_model, params)
+        # Presigned requests shouldn't use flexible checksums by default.
+        self.assertNotIn("checksum", request["context"])
+
     def test_request_checksum_algorithm_model_unsupported_algorithm(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model(
             http_checksum={"requestAlgorithmMember": "Algorithm"},
         )
-        params = {"Algorithm": "crc32"}
+        params = {"Algorithm": "crc64nvme"}
 
         with self.assertRaises(FlexibleChecksumError):
             resolve_request_checksum_algorithm(
                 request, operation_model, params, supported_algorithms=[]
             )
 
-    def test_request_checksum_algorithm_model_legacy_md5(self):
+    def test_request_checksum_algorithm_model_legacy_crc64nvme(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model(required=True)
         params = {}
 
         resolve_request_checksum_algorithm(request, operation_model, params)
+        expected_algorithm = {
+            "algorithm": "crc64nvme",
+            "in": "header",
+            "name": "x-amz-checksum-crc64nvme",
+        }
         actual_algorithm = request["context"]["checksum"]["request_algorithm"]
-        expected_algorithm = "conditional-md5"
         self.assertEqual(actual_algorithm, expected_algorithm)
 
-    def test_request_checksum_algorithm_model_new_md5(self):
+    def test_request_checksum_algorithm_model_new_crc64nvme(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model(
             http_checksum={"requestChecksumRequired": True}
@@ -190,7 +274,11 @@ class TestHttpChecksumHandlers(unittest.TestCase):
 
         resolve_request_checksum_algorithm(request, operation_model, params)
         actual_algorithm = request["context"]["checksum"]["request_algorithm"]
-        expected_algorithm = "conditional-md5"
+        expected_algorithm = {
+            "algorithm": "crc64nvme",
+            "in": "header",
+            "name": "x-amz-checksum-crc64nvme",
+        }
         self.assertEqual(actual_algorithm, expected_algorithm)
 
     def test_apply_request_checksum_handles_no_checksum_context(self):
@@ -198,77 +286,71 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         apply_request_checksum(request)
         # Build another request and assert the original request is the same
         expected_request = self._build_request(b"")
-        self.assertEqual(request, expected_request)
+        self.assertEqual(request["headers"], expected_request["headers"])
+        self.assertEqual(request["body"], expected_request["body"])
+        self.assertEqual(request["url"], expected_request["url"])
 
     def test_apply_request_checksum_handles_invalid_context(self):
         request = self._build_request(b"")
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "http-trailer",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
         with self.assertRaises(FlexibleChecksumError):
             apply_request_checksum(request)
 
-    def test_apply_request_checksum_conditional_md5(self):
-        request = self._build_request(b"")
-        request["context"]["checksum"] = {
-            "request_algorithm": "conditional-md5"
-        }
-        apply_request_checksum(request)
-        self.assertIn("Content-MD5", request["headers"])
-
     def test_apply_request_checksum_flex_header_bytes(self):
         request = self._build_request(b"")
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "header",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
         apply_request_checksum(request)
-        self.assertIn("x-amz-checksum-crc32", request["headers"])
+        self.assertIn("x-amz-checksum-crc64nvme", request["headers"])
 
     def test_apply_request_checksum_flex_header_readable(self):
         request = self._build_request(BytesIO(b""))
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "header",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
         apply_request_checksum(request)
-        self.assertIn("x-amz-checksum-crc32", request["headers"])
+        self.assertIn("x-amz-checksum-crc64nvme", request["headers"])
 
     def test_apply_request_checksum_flex_header_explicit_digest(self):
         request = self._build_request(b"")
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "header",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
-        request["headers"]["x-amz-checksum-crc32"] = "foo"
+        request["headers"]["x-amz-checksum-crc64nvme"] = "foo"
         apply_request_checksum(request)
         # The checksum should not have been modified
-        self.assertEqual(request["headers"]["x-amz-checksum-crc32"], "foo")
+        self.assertEqual(request["headers"]["x-amz-checksum-crc64nvme"], "foo")
 
     def test_apply_request_checksum_flex_trailer_bytes(self):
         request = self._build_request(b"")
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "trailer",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
         apply_request_checksum(request)
-        self.assertNotIn("x-amz-checksum-crc32", request["headers"])
+        self.assertNotIn("x-amz-checksum-crc64nvme", request["headers"])
         self.assertIsInstance(request["body"], AwsChunkedWrapper)
 
     def test_apply_request_checksum_flex_trailer_readable(self):
@@ -276,12 +358,12 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "trailer",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
         apply_request_checksum(request)
-        self.assertNotIn("x-amz-checksum-crc32", request["headers"])
+        self.assertNotIn("x-amz-checksum-crc64nvme", request["headers"])
         self.assertIsInstance(request["body"], AwsChunkedWrapper)
 
     def test_apply_request_checksum_flex_header_trailer_explicit_digest(self):
@@ -289,17 +371,61 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         request["context"]["checksum"] = {
             "request_algorithm": {
                 "in": "trailer",
-                "algorithm": "crc32",
-                "name": "x-amz-checksum-crc32",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
             }
         }
-        request["headers"]["x-amz-checksum-crc32"] = "foo"
+        request["headers"]["x-amz-checksum-crc64nvme"] = "foo"
         apply_request_checksum(request)
         # The checksum should not have been modified
-        self.assertEqual(request["headers"]["x-amz-checksum-crc32"], "foo")
+        self.assertEqual(request["headers"]["x-amz-checksum-crc64nvme"], "foo")
         # The body should not have been wrapped
         self.assertIsInstance(request["body"], bytes)
 
+    def test_apply_request_checksum_content_encoding_preset(self):
+        request = self._build_request(b"")
+        request["context"]["checksum"] = {
+            "request_algorithm": {
+                "in": "trailer",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
+            }
+        }
+        request["headers"]["Content-Encoding"] = "foo"
+        apply_request_checksum(request)
+        # The content encoding should only have been appended
+        self.assertEqual(
+            request["headers"]["Content-Encoding"], "foo,aws-chunked"
+        )
+
+    def test_apply_request_checksum_content_encoding_default(self):
+        request = self._build_request(b"")
+        request["context"]["checksum"] = {
+            "request_algorithm": {
+                "in": "trailer",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
+            }
+        }
+        apply_request_checksum(request)
+        self.assertEqual(request["headers"]["Content-Encoding"], "aws-chunked")
+
+    def test_apply_request_checksum_extra_headers(self):
+        request = self._build_request(b"")
+        request["context"]["checksum"] = {
+            "request_algorithm": {
+                "in": "trailer",
+                "algorithm": "crc64nvme",
+                "name": "x-amz-checksum-crc64nvme",
+            },
+            "request_algorithm_header": {
+                "name": "foo",
+                "value": "bar",
+            },
+        }
+        apply_request_checksum(request)
+        self.assertEqual(request["headers"]["foo"], "bar")
+
     def test_response_checksum_algorithm_no_model(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model()
@@ -307,7 +433,7 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         resolve_response_checksum_algorithms(request, operation_model, params)
         self.assertNotIn("checksum", request["context"])
 
-    def test_response_checksum_algorithm_model_opt_in(self):
+    def test_response_checksum_algorithm_model_default(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model(
             http_checksum={
@@ -590,6 +716,9 @@ class TestChecksumImplementations(unittest.TestCase):
     def test_crt_crc32c(self):
         self.assert_base64_checksum(CrtCrc32cChecksum, "yZRlqg==")
 
+    def test_crt_crc64nvme(self):
+        self.assert_base64_checksum(CrtCrc64NvmeChecksum, "jSnVw/bqjr4=")
+
 
 class TestStreamingChecksumBody(unittest.TestCase):
     def setUp(self):
