@@ -10,11 +10,6 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import mock
-import tempfile
-from mock import patch, Mock, MagicMock
-
-from botocore.compat import json
 from botocore.compat import OrderedDict
 
 from awscli.customizations.cloudformation.deployer import Deployer
