@@ -17,17 +17,11 @@ import json
 import gzip
 from datetime import datetime, timedelta
 from dateutil import parser, tz
-from mock import Mock, call
 from argparse import Namespace
 
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives.asymmetric import rsa
-from cryptography.hazmat.primitives.asymmetric.padding import PKCS1v15
-from cryptography.hazmat.primitives.serialization import Encoding, PublicFormat
+from awscrt.crypto import RSASignatureAlgorithm
 
-from awscli.compat import six
-from awscli.testutils import BaseAWSCommandParamsTest
+from awscli.testutils import mock, BaseAWSCommandParamsTest
 from awscli.customizations.cloudtrail.validation import DigestError, \
     extract_digest_key_date, normalize_date, format_date, DigestProvider, \
     DigestTraverser, create_digest_traverser, \
@@ -36,7 +30,10 @@ from awscli.customizations.cloudtrail.validation import DigestError, \
     InvalidDigestFormat, S3ClientProvider
 from awscli.testutils import unittest
 from awscli.customizations.exceptions import ParamValidationError
+from awscli.compat import BytesIO
 from botocore.exceptions import ClientError
+from tests import PublicPrivateKeyLoader
+from . import get_private_key_path, get_public_key_path
 
 START_DATE = parser.parse('20140810T000000Z')
 END_DATE = parser.parse('20150810T000000Z')
@@ -59,7 +56,7 @@ def create_mock_key_provider(key_list):
     for k in key_list:
         public_keys[k] = {'Fingerprint': k,
                           'Value': 'ffaa00'}
-    key_provider = Mock()
+    key_provider = mock.Mock()
     key_provider.get_public_keys.return_value = public_keys
     return key_provider
 
@@ -77,7 +74,7 @@ def create_scenario(actions, logs=None):
     keys = [str(i) for i in range(len(actions))]
     key_provider = create_mock_key_provider(keys)
     digest_provider = MockDigestProvider(actions, logs)
-    digest_validator = Mock()
+    digest_validator = mock.Mock()
 
     def validate(bucket, key, public_key, digest_data, digest_str):
         if '_invalid' in digest_data:
@@ -221,10 +218,10 @@ class TestValidation(unittest.TestCase):
         self.assertEqual('20150816T230550Z', extract_digest_key_date(arn))
 
     def test_creates_traverser(self):
-        mock_s3_provider = Mock()
+        mock_s3_provider = mock.Mock()
         traverser = create_digest_traverser(
-            trail_arn=TEST_TRAIL_ARN, cloudtrail_client=Mock(),
-            organization_client=Mock(),
+            trail_arn=TEST_TRAIL_ARN, cloudtrail_client=mock.Mock(),
+            organization_client=mock.Mock(),
             trail_source_region='us-east-1',
             s3_client_provider=mock_s3_provider,
             bucket='bucket', prefix='prefix')
@@ -235,10 +232,10 @@ class TestValidation(unittest.TestCase):
         self.assertEqual('foo', digest_provider.trail_name)
 
     def test_creates_traverser_account_id(self):
-        mock_s3_provider = Mock()
+        mock_s3_provider = mock.Mock()
         traverser = create_digest_traverser(
-            trail_arn=TEST_TRAIL_ARN, cloudtrail_client=Mock(),
-            organization_client=Mock(),
+            trail_arn=TEST_TRAIL_ARN, cloudtrail_client=mock.Mock(),
+            organization_client=mock.Mock(),
             trail_source_region='us-east-1',
             s3_client_provider=mock_s3_provider,
             bucket='bucket', prefix='prefix',
@@ -252,7 +249,7 @@ class TestValidation(unittest.TestCase):
             TEST_ORGANIZATION_ACCOUNT_ID, digest_provider.account_id)
 
     def test_creates_traverser_and_gets_trail_by_arn(self):
-        cloudtrail_client = Mock()
+        cloudtrail_client = mock.Mock()
         cloudtrail_client.describe_trails.return_value = {'trailList': [
             {'TrailARN': TEST_TRAIL_ARN,
              'S3BucketName': 'bucket', 'S3KeyPrefix': 'prefix',
@@ -261,8 +258,8 @@ class TestValidation(unittest.TestCase):
         traverser = create_digest_traverser(
             trail_arn=TEST_TRAIL_ARN, trail_source_region='us-east-1',
             cloudtrail_client=cloudtrail_client,
-            organization_client=Mock(),
-            s3_client_provider=Mock())
+            organization_client=mock.Mock(),
+            s3_client_provider=mock.Mock())
         self.assertEqual('bucket', traverser.starting_bucket)
         self.assertEqual('prefix', traverser.starting_prefix)
         digest_provider = traverser.digest_provider
@@ -271,7 +268,7 @@ class TestValidation(unittest.TestCase):
         self.assertEqual(TEST_ACCOUNT_ID, digest_provider.account_id)
 
     def test_create_traverser_organizational_trail_not_launched(self):
-        cloudtrail_client = Mock()
+        cloudtrail_client = mock.Mock()
         cloudtrail_client.describe_trails.return_value = {'trailList': [
             {'TrailARN': TEST_TRAIL_ARN,
              'S3BucketName': 'bucket', 'S3KeyPrefix': 'prefix'}
@@ -279,8 +276,8 @@ class TestValidation(unittest.TestCase):
         traverser = create_digest_traverser(
             trail_arn=TEST_TRAIL_ARN, trail_source_region='us-east-1',
             cloudtrail_client=cloudtrail_client,
-            organization_client=Mock(),
-            s3_client_provider=Mock())
+            organization_client=mock.Mock(),
+            s3_client_provider=mock.Mock())
         self.assertEqual('bucket', traverser.starting_bucket)
         self.assertEqual('prefix', traverser.starting_prefix)
         digest_provider = traverser.digest_provider
@@ -289,12 +286,12 @@ class TestValidation(unittest.TestCase):
         self.assertEqual(TEST_ACCOUNT_ID, digest_provider.account_id)
 
     def test_creates_traverser_and_gets_trail_by_arn_s3_bucket_specified(self):
-        cloudtrail_client = Mock()
+        cloudtrail_client = mock.Mock()
         traverser = create_digest_traverser(
             trail_arn=TEST_TRAIL_ARN, trail_source_region='us-east-1',
             cloudtrail_client=cloudtrail_client,
-            organization_client=Mock(),
-            s3_client_provider=Mock(),
+            organization_client=mock.Mock(),
+            s3_client_provider=mock.Mock(),
             bucket="bucket")
         self.assertEqual('bucket', traverser.starting_bucket)
         digest_provider = traverser.digest_provider
@@ -303,13 +300,13 @@ class TestValidation(unittest.TestCase):
         self.assertEqual(TEST_ACCOUNT_ID, digest_provider.account_id)
 
     def test_creates_traverser_and_gets_organization_id(self):
-        cloudtrail_client = Mock()
+        cloudtrail_client = mock.Mock()
         cloudtrail_client.describe_trails.return_value = {'trailList': [
             {'TrailARN': TEST_TRAIL_ARN,
              'S3BucketName': 'bucket', 'S3KeyPrefix': 'prefix',
              'IsOrganizationTrail': True}
         ]}
-        organization_client = Mock()
+        organization_client = mock.Mock()
         organization_client.describe_organization.return_value = {
             "Organization": {
                 "MasterAccountId": TEST_ACCOUNT_ID,
@@ -320,7 +317,7 @@ class TestValidation(unittest.TestCase):
             trail_arn=TEST_TRAIL_ARN, trail_source_region='us-east-1',
             cloudtrail_client=cloudtrail_client,
             organization_client=organization_client,
-            s3_client_provider=Mock(), account_id=TEST_ACCOUNT_ID)
+            s3_client_provider=mock.Mock(), account_id=TEST_ACCOUNT_ID)
         self.assertEqual('bucket', traverser.starting_bucket)
         self.assertEqual('prefix', traverser.starting_prefix)
         digest_provider = traverser.digest_provider
@@ -329,13 +326,13 @@ class TestValidation(unittest.TestCase):
         self.assertEqual(TEST_ORGANIZATION_ID, digest_provider.organization_id)
 
     def test_creates_traverser_organization_trail_missing_account_id(self):
-        cloudtrail_client = Mock()
+        cloudtrail_client = mock.Mock()
         cloudtrail_client.describe_trails.return_value = {'trailList': [
             {'TrailARN': TEST_TRAIL_ARN,
              'S3BucketName': 'bucket', 'S3KeyPrefix': 'prefix',
              'IsOrganizationTrail': True}
         ]}
-        organization_client = Mock()
+        organization_client = mock.Mock()
         organization_client.describe_organization.return_value = {
             "Organization": {
                 "MasterAccountId": TEST_ACCOUNT_ID,
@@ -347,7 +344,7 @@ class TestValidation(unittest.TestCase):
                 trail_arn=TEST_TRAIL_ARN, trail_source_region='us-east-1',
                 cloudtrail_client=cloudtrail_client,
                 organization_client=organization_client,
-                s3_client_provider=Mock())
+                s3_client_provider=mock.Mock())
 
 
 class TestSha256RSADigestValidator(unittest.TestCase):
@@ -363,7 +360,13 @@ class TestSha256RSADigestValidator(unittest.TestCase):
         self._digest_data['_signature'] = 'aeff'
 
     def test_validates_digests(self):
-        private_key = rsa.generate_private_key(65537, 512, default_backend())
+        (
+            public_key,
+            private_key,
+        ) = PublicPrivateKeyLoader.load_private_key_and_public_key(
+            get_private_key_path(),
+            get_public_key_path()
+        )
         sha256_hash = hashlib.sha256(self._inflated_digest)
         string_to_sign = "%s\n%s/%s\n%s\n%s" % (
             self._digest_data['digestEndTime'],
@@ -372,13 +375,14 @@ class TestSha256RSADigestValidator(unittest.TestCase):
             sha256_hash.hexdigest(),
             self._digest_data['previousDigestSignature'])
         to_sign = string_to_sign.encode()
-        signature = private_key.sign(to_sign, PKCS1v15(), hashes.SHA256())
+        signature = private_key.sign(
+            signature_algorithm=RSASignatureAlgorithm.PKCS1_5_SHA256,
+            digest=hashlib.sha256(to_sign).digest()
+        )
+
         self._digest_data['_signature'] = binascii.hexlify(signature)
         validator = Sha256RSADigestValidator()
-        public_key = private_key.public_key()
-        pub_bytes = public_key.public_bytes(Encoding.DER, PublicFormat.PKCS1)
-        public_key_b64 = base64.b64encode(pub_bytes)
-        validator.validate('b', 'k', public_key_b64, self._digest_data,
+        validator.validate('b', 'k', public_key, self._digest_data,
                            self._inflated_digest)
 
     def test_does_not_expose_underlying_key_decoding_error(self):
@@ -426,13 +430,13 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
                                                    day=parsed.day)
 
     def _get_mock_provider(self, s3_client):
-        mock_s3_client_provider = Mock()
+        mock_s3_client_provider = mock.Mock()
         mock_s3_client_provider.get_client.return_value = s3_client
         return DigestProvider(
             mock_s3_client_provider, TEST_ACCOUNT_ID, 'foo', 'us-east-1')
 
     def test_initializes_public_properties(self):
-        client = Mock()
+        client = mock.Mock()
         provider = DigestProvider(client, TEST_ACCOUNT_ID, 'foo', 'us-east-1')
         self.assertEqual(TEST_ACCOUNT_ID, provider.account_id)
         self.assertEqual('foo', provider.trail_name)
@@ -476,7 +480,7 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
         self.assertEqual(keys[4], digests[3])
 
     def test_calls_list_objects_correctly(self):
-        s3_client = Mock()
+        s3_client = mock.Mock()
         mock_paginate = s3_client.get_paginator.return_value.paginate
         mock_search = mock_paginate.return_value.search
         mock_search.return_value = []
@@ -491,8 +495,8 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
             Marker=marker.format(account=TEST_ACCOUNT_ID))
 
     def test_calls_list_objects_correctly_org_trails(self):
-        s3_client = Mock()
-        mock_s3_client_provider = Mock()
+        s3_client = mock.Mock()
+        mock_s3_client_provider = mock.Mock()
         mock_paginate = s3_client.get_paginator.return_value.paginate
         mock_search = mock_paginate.return_value.search
         mock_search.return_value = []
@@ -518,23 +522,23 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
         )
 
     def test_ensures_digest_has_proper_metadata(self):
-        out = six.BytesIO()
+        out = BytesIO()
         f = gzip.GzipFile(fileobj=out, mode="wb")
         f.write('{"foo":"bar"}'.encode())
         f.close()
         gzipped_data = out.getvalue()
-        s3_client = Mock()
+        s3_client = mock.Mock()
         s3_client.get_object.return_value = {
-            'Body': six.BytesIO(gzipped_data),
+            'Body': BytesIO(gzipped_data),
             'Metadata': {}}
         provider = self._get_mock_provider(s3_client)
         with self.assertRaises(DigestSignatureError):
             provider.fetch_digest('bucket', 'key')
 
     def test_ensures_digest_can_be_gzip_inflated(self):
-        s3_client = Mock()
+        s3_client = mock.Mock()
         s3_client.get_object.return_value = {
-            'Body': six.BytesIO('foo'.encode()),
+            'Body': BytesIO('foo'.encode()),
             'Metadata': {}}
         provider = self._get_mock_provider(s3_client)
         with self.assertRaises(InvalidDigestFormat):
@@ -542,14 +546,14 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
 
     def test_ensures_digests_can_be_json_parsed(self):
         json_str = '{{{'
-        out = six.BytesIO()
+        out = BytesIO()
         f = gzip.GzipFile(fileobj=out, mode="wb")
         f.write(json_str.encode())
         f.close()
         gzipped_data = out.getvalue()
-        s3_client = Mock()
+        s3_client = mock.Mock()
         s3_client.get_object.return_value = {
-            'Body': six.BytesIO(gzipped_data),
+            'Body': BytesIO(gzipped_data),
             'Metadata': {'signature': 'abc', 'signature-algorithm': 'SHA256'}}
         provider = self._get_mock_provider(s3_client)
         with self.assertRaises(InvalidDigestFormat):
@@ -557,14 +561,14 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
 
     def test_fetches_digests(self):
         json_str = '{"foo":"bar"}'
-        out = six.BytesIO()
+        out = BytesIO()
         f = gzip.GzipFile(fileobj=out, mode="wb")
         f.write(json_str.encode())
         f.close()
         gzipped_data = out.getvalue()
-        s3_client = Mock()
+        s3_client = mock.Mock()
         s3_client.get_object.return_value = {
-            'Body': six.BytesIO(gzipped_data),
+            'Body': BytesIO(gzipped_data),
             'Metadata': {'signature': 'abc', 'signature-algorithm': 'SHA256'}}
         provider = self._get_mock_provider(s3_client)
         result = provider.fetch_digest('bucket', 'key')
@@ -575,10 +579,10 @@ class TestDigestProvider(BaseAWSCommandParamsTest):
 
 class TestDigestTraverser(unittest.TestCase):
     def test_initializes_with_default_validator(self):
-        provider = Mock()
+        provider = mock.Mock()
         traverser = DigestTraverser(
             digest_provider=provider, starting_bucket='1',
-            starting_prefix='baz', public_key_provider=Mock())
+            starting_prefix='baz', public_key_provider=mock.Mock())
         self.assertEqual('1', traverser.starting_bucket)
         self.assertEqual('baz', traverser.starting_prefix)
         self.assertEqual(provider, traverser.digest_provider)
@@ -586,8 +590,8 @@ class TestDigestTraverser(unittest.TestCase):
     def test_ensures_public_keys_are_loaded(self):
         start_date = START_DATE
         end_date = END_DATE
-        digest_provider = Mock()
-        key_provider = Mock()
+        digest_provider = mock.Mock()
+        key_provider = mock.Mock()
         key_provider.get_public_keys.return_value = []
         traverser = DigestTraverser(
             digest_provider=digest_provider, starting_bucket='1',
@@ -603,7 +607,7 @@ class TestDigestTraverser(unittest.TestCase):
         end_date = END_DATE
         key_name = end_date.strftime(DATE_FORMAT) + '.json.gz'
         region = 'us-west-2'
-        digest_provider = Mock()
+        digest_provider = mock.Mock()
         digest_provider.trail_home_region = region
         digest_provider.load_digest_keys_in_range.return_value = [key_name]
         digest_provider.fetch_digest.return_value = (
@@ -616,7 +620,7 @@ class TestDigestTraverser(unittest.TestCase):
              'previousDigestSignature': 'xyz'},
             'abc'
         )
-        key_provider = Mock()
+        key_provider = mock.Mock()
         key_provider.get_public_keys.return_value = [{'Fingerprint': 'a'}]
         on_invalid, calls = collecting_callback()
         traverser = DigestTraverser(
@@ -643,14 +647,14 @@ class TestDigestTraverser(unittest.TestCase):
                   'digestStartTime': (end_date - timedelta(hours=1)).strftime(
                       DATE_FORMAT),
                   'digestEndTime': end_date.strftime(DATE_FORMAT)}
-        digest_provider = Mock()
+        digest_provider = mock.Mock()
         digest_provider.load_digest_keys_in_range.return_value = [
             key_name]
         digest_provider.fetch_digest.return_value = (digest, key_name)
-        key_provider = Mock()
+        key_provider = mock.Mock()
         public_keys = {'a': {'Fingerprint': 'a', 'Value': 'a'}}
         key_provider.get_public_keys.return_value = public_keys
-        digest_validator = Mock()
+        digest_validator = mock.Mock()
         traverser = DigestTraverser(
             digest_provider=digest_provider, starting_bucket='1',
             starting_prefix='baz', public_key_provider=key_provider,
@@ -669,11 +673,11 @@ class TestDigestTraverser(unittest.TestCase):
                   'digestS3Bucket': 'not_same',
                   'digestS3Object': key_name,
                   'digestEndTime': end_date.strftime(DATE_FORMAT)}
-        digest_provider = Mock()
+        digest_provider = mock.Mock()
         digest_provider.load_digest_keys_in_range.return_value = [key_name]
         digest_provider.fetch_digest.return_value = (digest, key_name)
-        key_provider = Mock()
-        digest_validator = Mock()
+        key_provider = mock.Mock()
+        digest_validator = mock.Mock()
         traverser = DigestTraverser(
             digest_provider=digest_provider, starting_bucket='1',
             starting_prefix='baz', public_key_provider=key_provider,
@@ -823,11 +827,11 @@ class TestDigestTraverser(unittest.TestCase):
                       DATE_FORMAT),
                   'digestEndTime': end_timestamp,
                   '_signature': '123'}
-        digest_provider = Mock()
+        digest_provider = mock.Mock()
         digest_provider.load_digest_keys_in_range.return_value = [
             end_timestamp]
         digest_provider.fetch_digest.return_value = (digest, end_timestamp)
-        key_provider = Mock()
+        key_provider = mock.Mock()
         public_keys = {'a': {'Fingerprint': 'a', 'Value': 'a'}}
         key_provider.get_public_keys.return_value = public_keys
         digest_validator = Sha256RSADigestValidator()
@@ -845,39 +849,39 @@ class TestDigestTraverser(unittest.TestCase):
 
 class TestCloudTrailCommand(BaseAWSCommandParamsTest):
     def test_s3_client_created_lazily(self):
-        session = Mock()
+        session = mock.Mock()
         command = CloudTrailValidateLogs(session)
-        parsed_globals = Mock(region=None, verify_ssl=None, endpoint_url=None)
+        parsed_globals = mock.Mock(region=None, verify_ssl=None, endpoint_url=None)
         command.setup_services(parsed_globals)
         create_client_calls = session.create_client.call_args_list
         self.assertEqual(
             create_client_calls,
             [
-                call('organizations', verify=None, region_name=None),
-                call('cloudtrail', verify=None, region_name=None)
+                mock.call('organizations', verify=None, region_name=None),
+                mock.call('cloudtrail', verify=None, region_name=None)
             ]
         )
 
     def test_endpoint_url_is_used_for_cloudtrail(self):
         endpoint_url = 'https://mycloudtrail.aws.amazon.com/'
-        session = Mock()
+        session = mock.Mock()
         command = CloudTrailValidateLogs(session)
-        parsed_globals = Mock(region='foo', verify_ssl=None,
+        parsed_globals = mock.Mock(region='foo', verify_ssl=None,
                               endpoint_url=endpoint_url)
         command.setup_services(parsed_globals)
         create_client_calls = session.create_client.call_args_list
         self.assertEqual(
             create_client_calls,
             [
-                call('organizations', verify=None, region_name='foo'),
+                mock.call('organizations', verify=None, region_name='foo'),
                 # Here we should inject the endpoint_url only for cloudtrail.
-                call('cloudtrail', verify=None, region_name='foo',
+                mock.call('cloudtrail', verify=None, region_name='foo',
                      endpoint_url=endpoint_url)
             ]
         )
 
     def test_initializes_args(self):
-        session = Mock()
+        session = mock.Mock()
         command = CloudTrailValidateLogs(session)
         start_date = START_DATE.strftime(DATE_FORMAT)
         args = Namespace(trail_arn='abc', verbose=True,
@@ -895,20 +899,20 @@ class TestCloudTrailCommand(BaseAWSCommandParamsTest):
 
 class TestS3ClientProvider(BaseAWSCommandParamsTest):
     def test_creates_clients_for_buckets_in_us_east_1(self):
-        session = Mock()
-        s3_client = Mock()
+        session = mock.Mock()
+        s3_client = mock.Mock()
         session.create_client.return_value = s3_client
         s3_client.get_bucket_location.return_value = {'LocationConstraint': ''}
         provider = S3ClientProvider(session)
         created_client = provider.get_client('foo')
         self.assertEqual(s3_client, created_client)
         create_client_calls = session.create_client.call_args_list
-        self.assertEqual(create_client_calls, [call('s3', 'us-east-1')])
+        self.assertEqual(create_client_calls, [mock.call('s3', 'us-east-1')])
         self.assertEqual(1, s3_client.get_bucket_location.call_count)
 
     def test_creates_clients_for_buckets_outside_us_east_1(self):
-        session = Mock()
-        s3_client = Mock()
+        session = mock.Mock()
+        s3_client = mock.Mock()
         session.create_client.return_value = s3_client
         s3_client.get_bucket_location.return_value = {
             'LocationConstraint': 'us-west-2'}
@@ -917,14 +921,14 @@ class TestS3ClientProvider(BaseAWSCommandParamsTest):
         self.assertEqual(s3_client, created_client)
         create_client_calls = session.create_client.call_args_list
         self.assertEqual(create_client_calls, [
-            call('s3', 'us-west-1'),
-            call('s3', 'us-west-2')
+            mock.call('s3', 'us-west-1'),
+            mock.call('s3', 'us-west-2')
         ])
         self.assertEqual(1, s3_client.get_bucket_location.call_count)
 
     def test_caches_previously_loaded_bucket_regions(self):
-        session = Mock()
-        s3_client = Mock()
+        session = mock.Mock()
+        s3_client = mock.Mock()
         session.create_client.return_value = s3_client
         s3_client.get_bucket_location.return_value = {'LocationConstraint': ''}
         provider = S3ClientProvider(session)
@@ -938,8 +942,8 @@ class TestS3ClientProvider(BaseAWSCommandParamsTest):
         self.assertEqual(2, s3_client.get_bucket_location.call_count)
 
     def test_caches_previously_loaded_clients(self):
-        session = Mock()
-        s3_client = Mock()
+        session = mock.Mock()
+        s3_client = mock.Mock()
         session.create_client.return_value = s3_client
         s3_client.get_bucket_location.return_value = {'LocationConstraint': ''}
         provider = S3ClientProvider(session)
@@ -951,8 +955,8 @@ class TestS3ClientProvider(BaseAWSCommandParamsTest):
     def test_removes_cli_error_events(self):
         # We should also remove the error handler for S3.
         # This can be removed once the client switchover is done.
-        session = Mock()
-        s3_client = Mock()
+        session = mock.Mock()
+        s3_client = mock.Mock()
         session.create_client.return_value = s3_client
         s3_client.get_bucket_location.return_value = {'LocationConstraint': ''}
         provider = S3ClientProvider(session)
