@@ -12,11 +12,10 @@
 # language governing permissions and limitations under the License.
 
 from argparse import Namespace
-from mock import MagicMock, call
 from awscli.customizations.codedeploy.deregister import Deregister
 from awscli.customizations.exceptions import ConfigurationError
 from awscli.customizations.exceptions import ParamValidationError
-from awscli.testutils import unittest
+from awscli.testutils import mock, unittest
 
 
 class TestDeregister(unittest.TestCase):
@@ -40,7 +39,7 @@ class TestDeregister(unittest.TestCase):
         self.globals.endpoint_url = self.endpoint_url
         self.globals.verify_ssl = False
 
-        self.codedeploy = MagicMock()
+        self.codedeploy = mock.MagicMock()
         self.codedeploy.get_on_premises_instance.return_value = {
             'instanceInfo': {
                 'iamUserArn': self.iam_user_arn,
@@ -48,12 +47,12 @@ class TestDeregister(unittest.TestCase):
             }
         }
 
-        self.iam = MagicMock()
-        self.list_user_policies = MagicMock()
+        self.iam = mock.MagicMock()
+        self.list_user_policies = mock.MagicMock()
         self.list_user_policies.paginate.return_value = [
             {'PolicyNames': [self.policy_name]}
         ]
-        self.list_access_keys = MagicMock()
+        self.list_access_keys = mock.MagicMock()
         self.list_access_keys.paginate.return_value = [
             {'AccessKeyMetadata': [{'AccessKeyId': self.access_key_id}]}
         ]
@@ -61,7 +60,7 @@ class TestDeregister(unittest.TestCase):
             self.list_user_policies, self.list_access_keys
         ]
 
-        self.session = MagicMock()
+        self.session = mock.MagicMock()
         self.session.create_client.side_effect = [self.codedeploy, self.iam]
         self.deregister = Deregister(self.session)
 
@@ -81,13 +80,13 @@ class TestDeregister(unittest.TestCase):
     def test_deregister_creates_clients(self):
         self.deregister._run_main(self.args, self.globals)
         self.session.create_client.assert_has_calls([
-            call(
+            mock.call(
                 'codedeploy',
                 region_name=self.region,
                 endpoint_url=self.endpoint_url,
                 verify=self.globals.verify_ssl
             ),
-            call('iam', region_name=self.region)
+            mock.call('iam', region_name=self.region)
         ])
 
     def test_deregister_with_tags(self):
@@ -153,8 +152,8 @@ class TestDeregister(unittest.TestCase):
                 instanceName=self.instance_name
             )
         self.iam.get_paginator.assert_has_calls([
-            call('list_user_policies'),
-            call('list_access_keys')
+            mock.call('list_user_policies'),
+            mock.call('list_access_keys')
         ])
         self.list_user_policies.paginate.assert_called_with(
             UserName=self.instance_name
