@@ -10,11 +10,10 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import mock
 import os
 
 from awscli.customizations.configure.set import ConfigureSetCommand
-from awscli.testutils import unittest
+from awscli.testutils import mock, unittest
 from . import FakeSession
 
 
