@@ -13,28 +13,27 @@
 
 import glob
 import os
-import mock
-import tempfile
 import shutil
 import sys
+import tempfile
+from argparse import Namespace
+
 import botocore
 from botocore.compat import OrderedDict
 
-from awscli.testutils import unittest
-from awscli.customizations.utils import uni_print
 import awscli.customizations.eks.kubeconfig as kubeconfig
-from awscli.customizations.eks.update_kubeconfig import (KubeconfigSelector,
-                                                         EKSClient,
-                                                         API_VERSION)
-from awscli.customizations.eks.exceptions import (EKSError,
-                                                  EKSClusterError)
+from awscli.customizations.eks.exceptions import EKSClusterError, EKSError
 from awscli.customizations.eks.ordered_yaml import ordered_yaml_load
-from tests.functional.eks.test_util import get_testdata
-from tests.functional.eks.test_util import (describe_cluster_response,
-                                            describe_cluster_response_outpost_cluster,
-                                            describe_cluster_no_status_response,
-                                            describe_cluster_creating_response,
-                                            describe_cluster_deleting_response)
+from awscli.customizations.eks.update_kubeconfig import (API_VERSION,
+                                                         EKSClient,
+                                                         KubeconfigSelector)
+from awscli.customizations.utils import uni_print
+from awscli.testutils import mock, unittest
+from tests.functional.eks.test_util import (
+    describe_cluster_creating_response, describe_cluster_deleting_response,
+    describe_cluster_no_status_response, describe_cluster_response,
+    describe_cluster_response_outpost_cluster, get_testdata)
+
 
 def generate_env_variable(files):
     """
@@ -218,10 +217,10 @@ class TestEKSClient(unittest.TestCase):
         self._session.create_client.return_value = self._mock_client
         self._session.profile = None
 
-        self._client = EKSClient(self._session, "ExampleCluster", None)
+        self._client = EKSClient(self._session, parsed_args=Namespace(cluster_name="ExampleCluster", role_arn=None))
 
     def test_get_cluster_description(self):
-        self.assertEqual(self._client._get_cluster_description(),
+        self.assertEqual(self._client.cluster_description,
                          describe_cluster_response()["cluster"])
         self._mock_client.describe_cluster.assert_called_once_with(
             name="ExampleCluster"
@@ -231,8 +230,8 @@ class TestEKSClient(unittest.TestCase):
     def test_get_cluster_description_no_status(self):
         self._mock_client.describe_cluster.return_value = \
             describe_cluster_no_status_response()
-        self.assertRaises(EKSClusterError,
-                          self._client._get_cluster_description)
+        with self.assertRaises(EKSClusterError):
+            self._client.cluster_description
         self._mock_client.describe_cluster.assert_called_once_with(
             name="ExampleCluster"
         )
@@ -277,8 +276,8 @@ class TestEKSClient(unittest.TestCase):
     def test_cluster_creating(self):
         self._mock_client.describe_cluster.return_value =\
                                            describe_cluster_creating_response()
-        self.assertRaises(EKSClusterError,
-                          self._client._get_cluster_description)
+        with self.assertRaises(EKSClusterError):
+            self._client.cluster_description
         self._mock_client.describe_cluster.assert_called_once_with(
             name="ExampleCluster"
         )
@@ -287,8 +286,8 @@ class TestEKSClient(unittest.TestCase):
     def test_cluster_deleting(self):
         self._mock_client.describe_cluster.return_value =\
                                            describe_cluster_deleting_response()
-        self.assertRaises(EKSClusterError,
-                          self._client._get_cluster_description)
+        with self.assertRaises(EKSClusterError):
+            self._client.cluster_description
         self._mock_client.describe_cluster.assert_called_once_with(
             name="ExampleCluster"
         )
