@@ -13,8 +13,7 @@
 
 from awscli.customizations.emr import exceptions
 from awscli.customizations.emr.configutils import ConfigWriter
-from awscli.testutils import BaseAWSCommandParamsTest
-import mock
+from awscli.testutils import mock, BaseAWSCommandParamsTest
 
 
 class EMRBaseAWSCommandParamsTest(BaseAWSCommandParamsTest):
