@@ -13,7 +13,8 @@
 
 import os
 import copy
-import mock
+
+from awscli.testutils import mock
 
 from tests.unit.customizations.emr import EMRBaseAWSCommandParamsTest as \
     BaseAWSCommandParamsTest
