@@ -5,8 +5,7 @@ from awscli.customizations.emr.ssh import Get
 from awscli.customizations.emr.ssh import Put
 from awscli.customizations.emr.ssh import SSH
 from awscli.customizations.emr.ssh import Socks
-from awscli.testutils import BaseAWSHelpOutputTest
-import mock
+from awscli.testutils import mock, BaseAWSHelpOutputTest
 from tests.unit.customizations.emr import EMRBaseAWSCommandParamsTest as \
     BaseAWSCommandParamsTest
 
