@@ -12,7 +12,7 @@
 # language governing permissions and limitations under the License.
 import os
 import platform
-from awscli.testutils import unittest, FileCreator, BaseAWSCommandParamsTest
+from awscli.testutils import mock, unittest, FileCreator, BaseAWSCommandParamsTest
 from awscli.testutils import skip_if_windows
 import stat
 import tempfile
@@ -20,8 +20,6 @@ import shutil
 import socket
 
 from botocore.exceptions import ClientError
-from awscli.compat import six
-import mock
 
 from awscli.customizations.s3.filegenerator import FileGenerator, \
     FileDecodingError, FileStat, is_special_file, is_readable
@@ -122,7 +120,7 @@ class LocalFileGeneratorTest(unittest.TestCase):
         ref_list = [file_stat]
         self.assertEqual(len(result_list), len(ref_list))
         for i in range(len(result_list)):
-            compare_files(self, result_list[i], ref_list[i])
+            compare_files(result_list[i], ref_list[i])
 
     def test_local_directory(self):
         """
@@ -155,7 +153,7 @@ class LocalFileGeneratorTest(unittest.TestCase):
         ref_list = [file_stat2, file_stat]
         self.assertEqual(len(result_list), len(ref_list))
         for i in range(len(result_list)):
-            compare_files(self, result_list[i], ref_list[i])
+            compare_files(result_list[i], ref_list[i])
 
 
 @skip_if_windows('Symlink tests only supported on mac/linux')
@@ -312,7 +310,7 @@ class TestSymlinksIgnoreFiles(unittest.TestCase):
         self.files.remove_all()
 
     def test_no_follow_symlink(self):
-        abs_root = six.text_type(os.path.abspath(self.root) + os.sep)
+        abs_root = str(os.path.abspath(self.root) + os.sep)
         input_local_dir = {'src': {'path': abs_root,
                                    'type': 'local'},
                            'dest': {'path': self.bucket,
@@ -326,14 +324,14 @@ class TestSymlinksIgnoreFiles(unittest.TestCase):
         self.assertEqual(len(result_list), len(self.filenames))
         # Just check to make sure the right local files are generated.
         for i in range(len(result_list)):
-            filename = six.text_type(os.path.abspath(self.filenames[i]))
+            filename = str(os.path.abspath(self.filenames[i]))
             self.assertEqual(result_list[i], filename)
 
     def test_warn_bad_symlink(self):
         """
         This tests to make sure it fails when following bad symlinks.
         """
-        abs_root = six.text_type(os.path.abspath(self.root) + os.sep)
+        abs_root = str(os.path.abspath(self.root) + os.sep)
         input_local_dir = {'src': {'path': abs_root,
                                    'type': 'local'},
                            'dest': {'path': self.bucket,
@@ -350,14 +348,14 @@ class TestSymlinksIgnoreFiles(unittest.TestCase):
         self.assertEqual(len(result_list), len(all_filenames))
         # Just check to make sure the right local files are generated.
         for i in range(len(result_list)):
-            filename = six.text_type(os.path.abspath(all_filenames[i]))
+            filename = str(os.path.abspath(all_filenames[i]))
             self.assertEqual(result_list[i], filename)
         self.assertFalse(file_gen.result_queue.empty())
 
     def test_follow_symlink(self):
         # First remove the bad symlink.
         os.remove(os.path.join(self.root, 'symlink_2'))
-        abs_root = six.text_type(os.path.abspath(self.root) + os.sep)
+        abs_root = str(os.path.abspath(self.root) + os.sep)
         input_local_dir = {'src': {'path': abs_root,
                                    'type': 'local'},
                            'dest': {'path': self.bucket,
@@ -372,7 +370,7 @@ class TestSymlinksIgnoreFiles(unittest.TestCase):
         self.assertEqual(len(result_list), len(all_filenames))
         # Just check to make sure the right local files are generated.
         for i in range(len(result_list)):
-            filename = six.text_type(os.path.abspath(all_filenames[i]))
+            filename = str(os.path.abspath(all_filenames[i]))
             self.assertEqual(result_list[i], filename)
 
 
@@ -380,7 +378,7 @@ class TestListFilesLocally(unittest.TestCase):
     maxDiff = None
 
     def setUp(self):
-        self.directory = six.text_type(tempfile.mkdtemp())
+        self.directory = str(tempfile.mkdtemp())
 
     def tearDown(self):
         shutil.rmtree(self.directory)
@@ -512,7 +510,7 @@ class S3FileGeneratorTest(BaseAWSCommandParamsTest):
         ref_list = [file_stat]
         self.assertEqual(len(result_list), len(ref_list))
         for i in range(len(result_list)):
-            compare_files(self, result_list[i], ref_list[i])
+            compare_files(result_list[i], ref_list[i])
 
     def test_s3_single_file_404(self):
         """
@@ -543,7 +541,6 @@ class S3FileGeneratorTest(BaseAWSCommandParamsTest):
         result_list = list(file_gen.call(input_s3_file))
         self.assertEqual(len(result_list), 1)
         compare_files(
-            self,
             result_list[0],
             FileStat(src=self.file1, dest='text1.txt',
                      compare_key='text1.txt',
@@ -594,7 +591,7 @@ class S3FileGeneratorTest(BaseAWSCommandParamsTest):
         ref_list = [file_stat, file_stat2]
         self.assertEqual(len(result_list), len(ref_list))
         for i in range(len(result_list)):
-            compare_files(self, result_list[i], ref_list[i])
+            compare_files(result_list[i], ref_list[i])
 
     def test_s3_delete_directory(self):
         """
@@ -644,7 +641,7 @@ class S3FileGeneratorTest(BaseAWSCommandParamsTest):
         ref_list = [file_stat1, file_stat2, file_stat3]
         self.assertEqual(len(result_list), len(ref_list))
         for i in range(len(result_list)):
-            compare_files(self, result_list[i], ref_list[i])
+            compare_files(result_list[i], ref_list[i])
 
 
 if __name__ == "__main__":
