@@ -12,12 +12,11 @@
 # language governing permissions and limitations under the License.
 import json
 
-import mock
 from botocore import xform_name
 from botocore import model
 from botocore.compat import OrderedDict
 
-from awscli.testutils import unittest
+from awscli.testutils import mock, unittest
 from awscli.testutils import BaseCLIDriverTest
 from awscli.testutils import temporary_file
 from awscli.help import OperationHelpCommand
