@@ -20,7 +20,6 @@
 # distribution when running the tests.
 import os
 import sys
-import mock
 import time
 import random
 import shutil
@@ -35,15 +34,17 @@ from subprocess import Popen, PIPE
 
 from dateutil.tz import tzlocal
 import unittest
+from unittest import mock
 
 import botocore.loaders
 import botocore.session
 from botocore.awsrequest import AWSResponse
-from botocore.compat import six
 from botocore.compat import urlparse
 from botocore.compat import parse_qs
 from botocore import utils
 from botocore import credentials
+from botocore.httpchecksum import _CHECKSUM_CLS, DEFAULT_CHECKSUM_ALGORITHM
+from botocore.configprovider import create_botocore_default_config_mapping
 from botocore.stub import Stubber
 
 
@@ -105,6 +106,11 @@ def create_session(**kwargs):
     return session
 
 
+def get_botocore_default_config_mapping():
+    session = botocore.session.get_session()
+    return create_botocore_default_config_mapping(session)
+
+
 @contextlib.contextmanager
 def temporary_file(mode):
     """This is a cross platform temporary file creation.
@@ -350,7 +356,7 @@ class IntegerRefresher(credentials.RefreshableCredentials):
 
 
 def _urlparse(url):
-    if isinstance(url, six.binary_type):
+    if isinstance(url, bytes):
         # Not really necessary, but it helps to reduce noise on Python 2.x
         url = url.decode('utf8')
     return urlparse(url)
@@ -591,3 +597,14 @@ def patch_load_service_model(
 
     loader = session.get_component('data_loader')
     monkeypatch.setattr(loader, 'load_service_model', mock_load_service_model)
+
+
+def get_checksum_cls(algorithm=DEFAULT_CHECKSUM_ALGORITHM.lower()):
+    """
+    This pass through is grabbing our internally supported list of checksums
+    to ensure we stay in sync, while not exposing them publicly.
+
+    Returns a checksum algorithm class. The default checksum class is used
+    if one isn't specified.
+    """
+    return _CHECKSUM_CLS[algorithm]
